@@ -1219,7 +1219,7 @@ gboolean full_char_proc(KeySym keysym)
     return 1;
   }
 
-  if (current_method_type() == 6 && current_CS->im_state == GCIN_STATE_CHINESE)
+  if (current_method_type() == method_type_TSIN && current_CS->im_state == GCIN_STATE_CHINESE)
     add_to_tsin_buf_str(tt);
   else
   if (gtab_phrase_on() && ggg.gbufN)
