@@ -356,6 +356,7 @@ void kbm_toggle()
 
 
 void reload_tsin_db();
+void reload_en_db();
 void do_exit();
 
 void message_cb(char *message)
@@ -379,6 +380,7 @@ void message_cb(char *message)
 #endif
    if (!strcmp(message, RELOAD_TSIN_DB)) {
      reload_tsin_db();
+     reload_en_db();
    } else
    if (!strcmp(message, GCIN_EXIT_MESSAGE)) {
      do_exit();
@@ -426,6 +428,7 @@ void destroy_win1();
 void destroy_win_gtab();
 void free_pho_mem(),free_tsin(), free_en(), free_all_IC(), free_gtab(), free_phrase(), destroy_tray_win32(), free_gcb();
 void close_pho_fw();
+void close_gtab_use_count();
 
 void do_exit()
 {
@@ -434,6 +437,7 @@ void do_exit()
   free_pho_mem();
   free_tsin();
   free_en();
+  close_gtab_use_count();
 #if USE_XIM
   free_all_IC();
 #endif
@@ -549,17 +553,19 @@ int main(int argc, char **argv)
   gtk_init (&argc, &argv);
 
 #if GTK_CHECK_VERSION(2,91,6)
+#if 1
   static char css[]=
-"GtkButton\n"
-"{\n"
-"  border-width: 0 0 0 0\n"
-"  padding: 0 0 0 0\n"
-"  -GtkButton-inner-border: 0\n"
+"button {\n"
+"border-width: 0 0 0 0;\n"
+"margin: 0 0 0 0;\n"
+"padding: 0 0 0 0;\n"
+"border-radius: 0;\n"
 "}";
   GtkCssProvider *provider = gtk_css_provider_new();
   gtk_css_provider_load_from_data(provider, css, -1, NULL);
   gtk_style_context_add_provider_for_screen(gdk_display_get_default_screen(gdk_display_get_default()), GTK_STYLE_PROVIDER(provider), GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
   g_object_unref(provider);
+#endif  
 #else
 static char button_rc[]="style \"button\"\n"
 "{\n"
