@@ -180,5 +180,5 @@ void win32_init_win(GtkWidget *win);
 #define BITON(flag, bit) ((flag) & (bit))
 
 typedef int usecount_t;
-
-#define MAX_CIN_PHR (100*CH_SZ + 1)
+#define MAX_CIN_PHR_N 100
+#define MAX_CIN_PHR (MAX_CIN_PHR_N*CH_SZ + 1)
