@@ -224,24 +224,29 @@ static char *gen_buf_str_disp()
 
 void disp_label_edit(char *str);
 
-static void free_pgbuf(GEDIT *p)
-{
-  int i;
-  for(i=0; i < p->selN; i++)
-    free(p->sel[i]);
-  free(p->sel);
+static void free_pgbuf(GEDIT *p) {
+  if (p->sel) {
+      int i;
+      for (i = 0; i < p->selN; i++) {
+          free(p->sel[i]);
+          p->sel[i] = NULL;
+      }
+      free(p->sel);
+      p->sel = NULL;
+  }
+
   p->ch = NULL;
-  p->sel=NULL;
+  p->selN = 0;
   p->flag = 0;
 }
 
-
 static void free_gbuf(int idx)
 {
-  free_pgbuf(&gbuf[idx]);
+    if (!gbuf || idx >= ggg.gbufN || idx < 0)
+        return;
+    free_pgbuf(&gbuf[idx]);
 }
 
-
 void clear_gtab_buf_all()
 {
   int i;
@@ -279,6 +284,7 @@ void clear_gbuf_sel()
 #endif
   ggg.gtab_buf_select = 0;
   ggg.total_matchN = 0;
+  ggg.pg_idx = 0;
   ClrSelArea();
 }
 
@@ -729,7 +735,8 @@ void insert_gbuf_nokey(char *s)
    dbg("insert_gbuf_nokey %s\n", s);
 
    int i;
-   u_int64_t keys[32];
+#define MKEY 32   
+   u_int64_t keys[MKEY];
    int keysN=0;
    int sz = utf8_sz(s);
 
@@ -740,6 +747,8 @@ void insert_gbuf_nokey(char *s)
          u_int64_t t;
          memcpy(&t, cur_inmd->tbl64[i].key, sizeof(u_int64_t));
          keys[keysN++] = t;
+         if (keysN >= MKEY)
+           break;         
        }
      }
    } else
@@ -749,6 +758,8 @@ void insert_gbuf_nokey(char *s)
          u_int t;
          memcpy(&t, cur_inmd->tbl[i].key, sizeof(u_int));
          keys[keysN++] = t;
+         if (keysN >= MKEY)
+            break;         
        }
      }
    }
@@ -1064,7 +1075,7 @@ gboolean save_gtab_buf_shift_enter()
 {
 	int start = ggg.gbufN == ggg.gbuf_cursor ? 0:ggg.gbuf_cursor;
 	int N = ggg.gbufN - start;
-	if (!N)
+	if (!N || N > MAX_CIN_PHR_N)
 		return 0;
 #if WIN32
 	if (test_mode)
