@@ -992,6 +992,29 @@ void gen_kval() {
       vmaskci = cur_inmd->key64 ? vmask64_7[ggg.ci]:vmask_7[ggg.ci];
 }
 
+static void invalid_key_in() {
+	dbg("invalid_key_in\n");
+    if (gtab_invalid_key_in) {
+      if (ggg.spc_pressed) {
+        bell_err();
+        ggg.invalid_spc = TRUE;
+//        dbg("ggg.invalid_spc\n");
+      } else {
+        seltab[0][0]=0;
+        ClrSelArea();
+      }
+    } else {
+      if (gtab_dup_select_bell)
+        bell();
+
+      if (ggg.ci>0)
+        ggg.inch[--ggg.ci]=0;
+    }	
+    
+    ggg.last_idx=0;
+    DispInArea();    
+}	
+
 gboolean feedkey_gtab(KeySym key, int kbstate)
 {
   int i,j=0;
@@ -1084,7 +1107,7 @@ en_char:
 		dbg("bb ggg.gbuf_cursor %d %d\n", ggg.gbuf_cursor, ggg.gbufN);
         insert_gbuf_cursor_char(key);
 
-		if (ggg.gbuf_cursor==ggg.gbufN && strchr(" <>,./;-=?':[]_0123456789+$^&(){}|\\!@*#%\"`~",  key) != NULL) {
+		if (ggg.gbuf_cursor==ggg.gbufN && (strchr("<>,./;-=?':[]_0123456789+$^&(){}|\\!@*#%\"`~", key) != NULL || (key==' ' && !en_pre_select) )) {
 		  dbg("output\n");
 		  output_gbuf();
           return 1;
@@ -1294,7 +1317,7 @@ shift_proc:
           return 1;
         }
 next_page:
-//        dbg("more...\n");
+        dbg("more...pg_idx:%d page_len:%d\n", ggg.pg_idx, page_len());
         ggg.pg_idx += page_len();
         if (ggg.pg_idx >=ggg.E1)
           ggg.pg_idx = ggg.S1;
@@ -1309,7 +1332,8 @@ next_page:
         return FALSE;
       }
     case ' ':
-      hide_gtab_pre_sel();
+	  if (!ggg.more_pg)
+		hide_gtab_pre_sel();
 
       if (ggg.invalid_spc && gtab_invalid_key_in)
         ClrIn();
@@ -1321,7 +1345,7 @@ next_page:
 
       has_wild = has_wild_card();
 
-//      dbg("ggg.wild_mode:%d ggg.more_pg:%d ggg.ci:%d  has_wild:%d\n", ggg.wild_mode, ggg.more_pg, ggg.ci, has_wild);
+      dbg("ggg.wild_mode:%d ggg.more_pg:%d ggg.ci:%d  has_wild:%d\n", ggg.wild_mode, ggg.more_pg, ggg.ci, has_wild);
 
       if (ggg.wild_mode) {
         // request from tetralet
@@ -1338,13 +1362,13 @@ next_page:
         ggg.spc_pressed = TRUE;
         return 1;
       } else
-      if (ggg.more_pg && !(_gtab_space_auto_first & GTAB_space_auto_first_any)) {
+      if (ggg.more_pg && !(_gtab_space_auto_first & GTAB_space_auto_first_any)) {		  
         if (ggg.gtab_buf_select) {
           gbuf_next_pg();
           return 1;
         }
-        else
-          goto next_page;
+        else 
+          goto next_page;        
       } else
       if (ggg.ci==0) {
         if (ggg.gbufN) {
@@ -1397,7 +1421,7 @@ direct_select:
 
       ggg.last_full=0;
       ggg.spc_pressed=1;
-//      dbg("spc_pressed=1\n");
+      dbg("spc_pressed=1\n");
 
       if (has_wild) {
         ggg.wild_page=0;
@@ -1583,7 +1607,7 @@ keypad_proc:
         return 0;
       }
 
-//        dbg("ggg.spc_pressed %d %d %d is_keypad:%d\n", ggg.spc_pressed, ggg.last_full, cur_inmd->MaxPress, is_keypad);
+        dbg("ggg.spc_pressed %d %d %d is_keypad:%d\n", ggg.spc_pressed, ggg.last_full, cur_inmd->MaxPress, is_keypad);
 
 #if 1 // for dayi, testcase :  6 space keypad6
       int vv = pselkey - cur_inmd->selkey;
@@ -1626,7 +1650,7 @@ keypad_proc:
       }
 #endif
 
-//      dbg("iii %x sel1st_i:%d auto:%d\n", pselkey, ggg.sel1st_i, AUTO_SELECT_BY_PHRASE);
+      dbg("iii %x sel1st_i:%d auto:%d\n", pselkey, ggg.sel1st_i, AUTO_SELECT_BY_PHRASE);
       if (seltab[ggg.sel1st_i][0] && !ggg.wild_mode &&
            (gtab_full_space_auto_first||ggg.spc_pressed||ggg.last_full) ) {
         if (gtab_phrase_on_() && poo.same_pho_query_state != SAME_PHO_QUERY_gtab_input)
@@ -1832,14 +1856,12 @@ keypad_proc:
 
 
 #if 0
-  dbg("MaxPress:%d vmaskci:%llx kval:%llx ggg.ci:%d  !=%d  S1:%d  kval:%x\n", cur_inmd->MaxPress,
-  vmaskci, ggg.kval, ggg.ci,
-  ((CONVT2(cur_inmd, ggg.S1) & vmaskci)!=ggg.kval), ggg.S1);
+  dbg("MaxPress:%d vmaskci:%llx kval:%llx ggg.ci:%d  !=%d  S1:%d  CONV:%lx\n", cur_inmd->MaxPress,
+  vmaskci, ggg.kval, ggg.ci, ((CONVT2(cur_inmd, ggg.S1) & vmaskci)!=ggg.kval), ggg.S1, CONVT2(cur_inmd, ggg.S1));
 #endif
 
   if ((CONVT2(cur_inmd, ggg.S1) & vmaskci)!=ggg.kval || (ggg.wild_mode && ggg.defselN) ||
-                  ((/* ggg.ci==cur_inmd->MaxPress|| */ ggg.spc_pressed) && ggg.defselN &&
-      (pselkey && ( pendkey || ggg.spc_pressed)) ) ) {
+                    (ggg.spc_pressed && ggg.defselN && (pselkey && (pendkey || ggg.spc_pressed)) ) ) {
 YYYY:
 
     if ((pselkey || ggg.wild_mode) && ggg.defselN) {
@@ -1871,25 +1893,7 @@ YYYY:
     return 1;
 #endif
 
-    if (gtab_invalid_key_in) {
-      if (ggg.spc_pressed) {
-        bell_err();
-        ggg.invalid_spc = TRUE;
-//        dbg("ggg.invalid_spc\n");
-      } else {
-        seltab[0][0]=0;
-        ClrSelArea();
-      }
-    } else {
-      if (gtab_dup_select_bell)
-        bell();
-
-      if (ggg.ci>0)
-        ggg.inch[--ggg.ci]=0;
-    }
-
-    ggg.last_idx=0;
-    DispInArea();
+	invalid_key_in();
     return 1;
   }
 
@@ -1929,7 +1933,7 @@ refill:
     }
 
     ggg.defselN=ggg.exa_match;
-//    dbg("--- ggg.exa_match %d\n", ggg.exa_match);
+    dbg("--- ggg.exa_match %d\n", ggg.exa_match);
 
     if (ggg.defselN > page_len())
       ggg.defselN--;
@@ -1984,7 +1988,9 @@ nextj:
     }
 #endif
 
-    if (gtab_unique_auto_send_on()) {
+	dbg("gtab_unique_auto_send_on %d\n", gtab_unique_auto_send_on());
+
+    if (gtab_unique_auto_send_on()) {	
       char *first_str=NULL;
       for(i=0; i < page_len(); i++) {
         if (!seltab[i][0])
@@ -1993,6 +1999,8 @@ nextj:
           first_str = seltab[i];
       }
 
+	  dbg("match_cnt %d\n", match_cnt);
+
       if (match_cnt==1 && first_str) {
         if (gtab_phrase_on_() && poo.same_pho_query_state != SAME_PHO_QUERY_gtab_input)
           insert_gbuf_nokey(first_str);
@@ -2004,7 +2012,7 @@ nextj:
       }
     }
   } else {
-//    dbg("more %d %d  skip_end:%d\n", ggg.more_pg,  ggg.total_matchN, cur_inmd->flag&FLAG_PHRASE_AUTO_SKIP_ENDKEY);
+    dbg("more %d %d  skip_end:%d\n", ggg.more_pg,  ggg.total_matchN, cur_inmd->flag&FLAG_PHRASE_AUTO_SKIP_ENDKEY);
 next_pg:
     ggg.defselN=0;
     clr_seltab();
@@ -2025,20 +2033,24 @@ next_pg:
       int selN=0;
       char **sel = NULL;
 
-//     puts("kkkkkkkkkkk");
+//     dbg("kkkkkkkkkkk");
       while(j<ggg.E1 && CONVT2(cur_inmd, j)==ggg.kval && selN < 255) {
         sel = trealloc(sel, char *, selN+1);
         sel[selN++] = load_tblidx(j);
         j++;
-      }
-      insert_gbuf_cursor(sel, selN, ggg.kval, FALSE);
-      gtab_scan_pre_select(FALSE);
+      }      
+      if (!selN) {
+		  invalid_key_in();
+		  return 1;
+	  }        
+      insert_gbuf_cursor(sel, selN, ggg.kval, FALSE);      
+      gtab_scan_pre_select(FALSE);      
       clear_after_put();
       return 1;
     } else {
       j = ggg.pg_idx;
 
-//      dbg("jjjjjjjjjjjjjjjjjj");
+//      dbg("jjjjjjjjjjjjjjjjjj\n");
       while(j<ggg.E1 && CONVT2(cur_inmd, j)==ggg.kval && ggg.defselN < page_len()) {
         load_seltab(j, ggg.defselN);
 
