@@ -9,10 +9,16 @@ typedef struct {
   u_int seed;
   Connection_type type;
 #if	UNIX
+  GIOChannel *channel;
   int fd;
+#else
+#if SHARED_MEMORY
+  GCIN_SHM fd;
+  DWORD pid;
 #else
   HANDLE fd;
 #endif
+#endif
 } GCIN_ENT;
 
 extern GCIN_ENT *gcin_clients;
