@@ -84,11 +84,11 @@ void mask_key_typ_pho(phokey_t *key)
   if (!poo.typ_pho[3]) *key &= ~(7);
 }
 
-#define TKBM 1
+#define TKBM 0
 #define MIN_M_PHO 5
 
 // skip table for hsu
-phokey_t skip[]={
+static phokey_t skip[]={
 	0x1002, //ㄌ2
 	0x4604,  //
 	0x30, // ㄟ
@@ -100,6 +100,7 @@ phokey_t skip[]={
 	0xe00,  // ㄋ
 	0x1400, // ㄎ
 	0x1c00, // ㄒ
+	0x1200, // ㄍ
 	0x1c01, // ㄒ1 pho-huge
 	0x1c02, // ㄒ2 pho-huge
 	0x1c03, // ㄒ3 pho-huge
@@ -130,9 +131,9 @@ static void find_match_phos(u_char mtyp_pho[4],  int *mcount, int newkey)
 #endif
       for (vv = hash_pho[poo.typ_pho[0]]; vv < hash_pho[poo.typ_pho[0]+1]; vv++) {
         phokey_t ttt=idx_pho[vv].key;
-
+#if TKBM
 		prph(ttt);  dbg(" 0x%x\n", ttt);
-
+#endif
 		int j;
 		for(j=0; skip[j]; j++)
 			if (skip[j]==ttt)
@@ -156,12 +157,13 @@ static void find_match_phos(u_char mtyp_pho[4],  int *mcount, int newkey)
         if (ttt > key)
           break;
 
-		dbg(" ");  prph(ttt); dbg(" 0x%x\n", ttt);
+//		dbg(" ");  prph(ttt); dbg(" 0x%x\n", ttt);
 
         int count = 0;
 
         int i;
         for(i=idx_pho[vv].start; i < idx_pho[vv+1].start; i++) {
+//			dbg("%d %s",vv, pho_idx_str(i));
           if (utf8_sz(pho_idx_str(i)) > 1) {
 #if 0
             utf8_putchar(ch_pho[i].ch);
@@ -536,13 +538,19 @@ int ch_key_to_ch_pho_idx(phokey_t phkey, char *utf8)
 {
   int start_i, stop_i;
 
-  get_start_stop_idx(phkey, &start_i, &stop_i);
+  if (!get_start_stop_idx(phkey, &start_i, &stop_i))
+	return -1;
 
   int i;
   for(i=start_i; i<stop_i; i++) {
     char *ch = pho_idx_str(i);
+#if 0    
     int u8len = utf8_sz(ch);
-    if (!memcmp(ch, utf8, u8len)) {
+    if (!memcmp(ch, utf8, u8len)) 
+#else
+      if (!strcmp(ch, utf8))
+#endif    
+    {
       return i;
     }
   }
