@@ -4,7 +4,7 @@ void box_warn(char *fmt,...);
 char *sys_err_strA();
 
 #if DEBUG
-void __gcin_dbg_(char *fmt,...);
+void __gcin_dbg_(const char *fmt,...);
 #if GCIN_MODULE
 #define dbg(...) gmf.mf___gcin_dbg_(__VA_ARGS__)
 #else
