@@ -816,3 +816,21 @@ void change_tsin_color()
   drawcursor();
 }
 #endif
+
+
+void bell()
+{
+#if WIN32
+  if (test_mode)
+    return;
+#endif
+  if (gcin_bell_off)
+    return;
+
+#if UNIX && 1
+  XBell(dpy, gcin_bell_volume);
+#else
+  gdk_beep();
+#endif
+//  abort();
+}
